==> 0.0.11.tar.gz: lib/common/base/base_custom_grid_scroll_view.dart <==

import '../../../widget/custom/custom_icon.dart';
import '../../../widget/text/custom_text_default_italic_field.dart';
import '../../../widget/pages/page_empty_data_widget.dart';
import '../../../widget/pages/page_loading_ui_widget.dart';
import '../../../widget/pages/page_loading_widget.dart';
import 'package:easy_localization/src/public_ext.dart';
import 'package:flutter/material.dart';
import 'package:flutter_staggered_animations/flutter_staggered_animations.dart';
import 'package:infinite_scroll_pagination/infinite_scroll_pagination.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';
import 'package:scroll_to_index/scroll_to_index.dart';

import '../../remote/constants.dart';
import '../values/sizes.dart';

class BaseCustomGridScrollView<T> extends StatelessWidget {
  final PagingController<int, T> pagingController;
  final AutoScrollController? controller;
  final Function(T, int) itemBuilder;
  final bool? isLastPage;
  final String? message;
  final bool? isController;
  final VoidCallback onRefresh;
  final bool? isPrimary;
  final RefreshController refreshController;

  const BaseCustomGridScrollView({
    required this.pagingController,
    required this.itemBuilder,
    required this.controller,
    required this.onRefresh,
    required this.refreshController,
    this.isPrimary,
    this.isController = true,
    this.isLastPage = false,
    this.message,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SmartRefresher(
      physics: BouncingScrollPhysics(),
      header: WaterDropMaterialHeader(
        color: isPrimary == true
            ? Colors.white
            : Theme.of(context).primaryColorLight,
        backgroundColor: isPrimary == true
            ? Theme.of(context).primaryColorDark
            : Colors.white,
      ),
      enablePullDown: true,
      onRefresh: onRefresh,
      controller: refreshController,
      child: CustomScrollView(
        scrollDirection: Axis.vertical,
        physics: BouncingScrollPhysics(),
        shrinkWrap: true,
        slivers: [
          SliverPadding(
            padding: EdgeInsets.all(Sizes.PADDING_4),
            sliver: PagedSliverGrid<int, T>(
              pagingController: pagingController,
              gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                crossAxisSpacing: Sizes.WIDTH_10,
                mainAxisSpacing: Sizes.WIDTH_10,
                childAspectRatio: 0.46,
                crossAxisCount: 3,
              ),
              builderDelegate: PagedChildBuilderDelegate<T>(
                itemBuilder: (context, item, index) {
                  return AnimationConfiguration.staggeredGrid(
                      position: index,
                      columnCount: pageSize,
                      child: SlideAnimation(
                        duration: Duration(milliseconds: 100),
                        verticalOffset: 50,
                        child: FadeInAnimation(
                          duration: Duration(milliseconds: 100),
                          child:
                              FadeInAnimation(child: itemBuilder(item, index)),
                        ),
                      ));
                },
                newPageProgressIndicatorBuilder: (context) {
                  if (isLastPage == false) {
                    return LoadingPageWidget();
                  } else {
                    return Container();
                  }
                },
                noMoreItemsIndicatorBuilder: (context) {
                  var dataSize = pagingController.itemList?.length ?? 0;
                  if (dataSize > 10) {
                    return Container(
                      child: Column(
                        children: [
                          CustomIcon(icon: Icons.search_rounded),
                          CustomTextDefaultItalicField(
                              label: "text_no_more".tr())
                        ],
                      ),
                    );
                  } else {
                    return Container();
                  }
                },
                firstPageProgressIndicatorBuilder: (context) =>
                    LoadingUIPageWidget(isCart: false, msg: message),
                noItemsFoundIndicatorBuilder: (context) => EmptyUIPageWidget(
                  msg: message,
                  isBackgroundWhite: true,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.0.35.tar.gz: lib/common/base/base_custom_grid_scroll_view.dart <==

import '../../../widget/custom/custom_icon.dart';
import '../../../widget/text/custom_text_default_italic_field.dart';
import '../../../widget/pages/page_empty_data_widget.dart';
import '../../../widget/pages/page_loading_ui_widget.dart';
import '../../../widget/pages/page_loading_widget.dart';
import 'package:easy_localization/src/public_ext.dart';
import 'package:flutter/material.dart';
import 'package:flutter_staggered_animations/flutter_staggered_animations.dart';
import 'package:infinite_scroll_pagination/infinite_scroll_pagination.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';
import 'package:scroll_to_index/scroll_to_index.dart';

import '../../remote/constants.dart';
import '../values/sizes.dart';

class BaseCustomGridScrollView<T> extends StatelessWidget {
  final PagingController<int, T> pagingController;
  final AutoScrollController? controller;
  final Function(T, int) itemBuilder;
  final bool? isLastPage;
  final String? message;
  final bool? isController;
  final VoidCallback onRefresh;
  final bool? isPrimary;
  final RefreshController refreshController;

  const BaseCustomGridScrollView({
    required this.pagingController,
    required this.itemBuilder,
    required this.controller,
    required this.onRefresh,
    required this.refreshController,
    this.isPrimary,
    this.isController = true,
    this.isLastPage = false,
    this.message,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SmartRefresher(
      physics: BouncingScrollPhysics(),
      header: WaterDropMaterialHeader(
        color: isPrimary == true
            ? Colors.white
            : Theme.of(context).primaryColor,
        backgroundColor: isPrimary == true
            ? Theme.of(context).primaryColorLight
            : Colors.white,
      ),
      enablePullDown: true,
      onRefresh: onRefresh,
      controller: refreshController,
      child: CustomScrollView(
        scrollDirection: Axis.vertical,
        physics: BouncingScrollPhysics(),
        shrinkWrap: true,
        slivers: [
          SliverPadding(
            padding: EdgeInsets.all(Sizes.PADDING_4),
            sliver: PagedSliverGrid<int, T>(
              pagingController: pagingController,
              gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                crossAxisSpacing: Sizes.WIDTH_10,
                mainAxisSpacing: Sizes.WIDTH_10,
                childAspectRatio: 0.46,
                crossAxisCount: 3,
              ),
              builderDelegate: PagedChildBuilderDelegate<T>(
                itemBuilder: (context, item, index) {
                  return AnimationConfiguration.staggeredGrid(
                      position: index,
                      columnCount: pageSize,
                      child: SlideAnimation(
                        duration: Duration(milliseconds: 100),
                        verticalOffset: 50,
                        child: FadeInAnimation(
                          duration: Duration(milliseconds: 100),
                          child:
                              FadeInAnimation(child: itemBuilder(item, index)),
                        ),
                      ));
                },
                newPageProgressIndicatorBuilder: (context) {
                  if (isLastPage == false) {
                    return LoadingPageWidget();
                  } else {
                    return Container();
                  }
                },
                noMoreItemsIndicatorBuilder: (context) {
                  var dataSize = pagingController.itemList?.length ?? 0;
                  if (dataSize > 10) {
                    return Container(
                      child: Column(
                        children: [
                          CustomIcon(icon: Icons.search_rounded),
                          CustomTextDefaultItalicField(
                              label: "text_no_more".tr())
                        ],
                      ),
                    );
                  } else {
                    return Container();
                  }
                },
                firstPageProgressIndicatorBuilder: (context) =>
                    LoadingUIPageWidget(isCart: false, msg: message),
                noItemsFoundIndicatorBuilder: (context) => EmptyUIPageWidget(
                  msg: message,
                  isBackgroundWhite: true,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
